@@ -41,7 +41,7 @@
  *
  */
 
-/* $Id: socks.h,v 1.167 2003/07/01 13:21:17 michaels Exp $ */
+/* $Id: socks.h,v 1.168 2004/06/20 12:20:45 karls Exp $ */
 
 #ifndef _SOCKS_H_
 #define _SOCKS_H_
@@ -101,6 +101,23 @@ extern const int lintnoloop_socks_h;
 #endif  /* gethostbyname2 */
 #define gethostbyname2(name, af)			sys_gethostbyname2(name, af)
 
+#ifdef getaddrinfo
+#undef getaddrinfo
+#endif /* getaddrinfo */
+#define getaddrinfo(nodename, servname, hints, res)	\
+			sys_getaddrinfo(nodename, servname, hints, res)
+
+#ifdef getipnodebyname
+#undef getipnodebyname
+#endif /* getipnodebyname */
+#define getipnodebyname(name, af, flags, error_num)	\
+			sys_getipnodebyname(name, af, flags, error_num)
+
+#ifdef freehostent
+#undef freehostent
+#endif  /* freehostent */
+#define freehostent(ptr)				sys_freehostent(ptr)
+
 #ifdef getpeername
 #undef getpeername
 #endif  /* getpeername */
@@ -245,6 +262,14 @@ int Rbindresvport __P((int, struct sockaddr_in *));
 int Rrresvport __P((int *));
 struct hostent *Rgethostbyname __P((const char *));
 struct hostent *Rgethostbyname2 __P((const char *, int af));
+#if HAVE_GETADDRINFO
+int Rgetaddrinfo __P((const char *nodename, const char *servname,
+		      		const struct addrinfo *hints, struct addrinfo **res));
+#endif /* HAVE_GETADDRINFO */
+#if HAVE_GETIPNODEBYNAME
+struct hostent *Rgetipnodebyname __P((const char *, int, int, int *));
+void Rfreehostent __P((struct hostent *));
+#endif /* HAVE_GETIPNODEBYNAME */
 ssize_t Rwrite __P((int d, const void *buf, size_t nbytes));
 ssize_t Rwritev __P((int d, const struct iovec *iov, int iovcnt));
 ssize_t Rsend __P((int s, const void *msg, size_t len, int flags));
@@ -602,6 +627,7 @@ cc_socksfdv(int sig);
 
 int sys_rresvport __P((int *));
 int sys_bindresvport __P((int, struct sockaddr_in *));
+void sys_freehostent __P((struct hostent *));
 
 HAVE_PROT_READ_0 sys_read
 __P((HAVE_PROT_READ_1, HAVE_PROT_READ_2, HAVE_PROT_READ_3));
