@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 1998, 1999, 2000, 2001
+ * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004
  *      Inferno Nettverk A/S, Norway.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -46,16 +46,18 @@
 #include "common.h"
 
 static const char rcsid[] =
-"$Id: io.c,v 1.59 2002/06/05 10:09:09 michaels Exp $";
+"$Id: io.c,v 1.65 2005/01/24 10:24:22 karls Exp $";
 
 #if SOCKS_CLIENT && SOCKSLIBRARY_DYNAMIC
 
+#undef sendmsg
 #if HAVE_EXTRA_OSF_SYMBOLS
 #define sendmsg(s, msg, flags)			sys_Esendmsg(s, msg, flags)
 #else
 #define sendmsg(s, msg, flags)			sys_sendmsg(s, msg, flags)
 #endif  /* HAVE_EXTRA_OSF_SYMBOLS */
 
+#undef recvmsg
 #if HAVE_EXTRA_OSF_SYMBOLS
 #define recvmsg(s, msg, flags)			sys_Erecvmsg(s, msg, flags)
 #else
@@ -64,10 +66,12 @@ static const char rcsid[] =
 
 /* XXX needed on AIX apparently */
 #ifdef recvmsg_system
+#undef recvmsg
 #define recvmsg recvmsg_system
 #endif /* recvmsg_system */
 
 #ifdef sendmsg_system
+#undef sendmsg
 #define sendmsg sendmsg_system
 #endif /* sendmsg_system */
 
@@ -247,7 +251,7 @@ recvmsgn(s, msg, flags)
 		size_t leaked;
 		int d;
 
-		for (leaked = 0; leaked * sizeof(d) < CMSG_GETLEN(*msg); ++leaked) {
+		for (leaked = 0; CMSG_SPACE(leaked * sizeof(d)) < CMSG_TOTLEN(*msg); ++leaked) {
 			CMSG_GETOBJECT(d, CMSG_CONTROLDATA(*msg), leaked * sizeof(d));
 			close(d);
 		}
@@ -287,7 +291,8 @@ recvmsgn(s, msg, flags)
 
 					swarn("%s: %d bytes left", function, left);
 
-					for (leaked = 0; leaked * sizeof(d) < CMSG_GETLEN(*msg);
+					for (leaked = 0;
+					CMSG_SPACE(leaked * sizeof(d)) < (size_t)CMSG_TOTLEN(*msg);
 					++leaked) {
 						CMSG_GETOBJECT(d, CMSG_CONTROLDATA(*msg), leaked * sizeof(d));
 						close(d);
