@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 1998, 1999, 2000, 2001
+ * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004
  *      Inferno Nettverk A/S, Norway.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -44,7 +44,7 @@
 #include "common.h"
 
 static const char rcsid[] =
-"$Id: udp.c,v 1.126 2001/12/12 14:42:14 karls Exp $";
+"$Id: udp.c,v 1.129 2005/01/24 10:24:22 karls Exp $";
 
 /* ARGSUSED */
 ssize_t
@@ -96,8 +96,8 @@ Rsendto(s, msg, len, flags, to, tolen)
 	/* prefix a UDP header to the msg */
 	nlen = len;
 	/* LINTED warning: cast discards 'const' from pointer target type */
-	if ((nmsg = udpheader_add(fakesockaddr2sockshost(to, &host), (char *)msg,
-	&nlen, 0)) == NULL) {
+	if ((nmsg = udpheader_add(fakesockaddr2sockshost(to, &host),
+	(const char *)msg, &nlen, 0)) == NULL) {
 		errno = ENOBUFS;
 		return -1;
 	}
