@@ -45,7 +45,7 @@
 #include "config_parse.h"
 
 static const char rcsid[] =
-"$Id: serverconfig.c,v 1.182 2003/07/01 13:21:41 michaels Exp $";
+"$Id: serverconfig.c,v 1.186 2004/12/24 18:43:08 michaels Exp $";
 
 __BEGIN_DECLS
 
@@ -460,8 +460,10 @@ showconfig(sockscf)
 	slog(LOG_DEBUG, "userid:\n%s",
 	userids2string(&sockscf->uid, "", buf, sizeof(buf)));
 
-	slog(LOG_DEBUG, "child.maxidlenumber: %d",
-	sockscf->child.maxidlenumber);
+#if 0
+	slog(LOG_DEBUG, "child.maxidle: %d",
+	sockscf->child.maxidle);
+#endif
 
 	bufused = snprintfn(buf, sizeof(buf), "method(s): ");
 	for (i = 0; (size_t)i < sockscf->methodc; ++i)
@@ -583,7 +585,13 @@ resetconfig(void)
 	bzero(&sockscf.uid, sizeof(sockscf.uid));
 
 	/* childstate, some read from configfile, some not. */
-	sockscf.child.maxidlenumber = 0;
+#if 0
+#if DEBUG
+	sockscf.child.maxidle = SOCKD_FREESLOTS;
+#else
+	sockscf.child.maxidle = 0;
+#endif
+#endif
 }
 
 void
@@ -1181,10 +1189,13 @@ addrule(newrule, rulebase, client)
 			yywarn("method \"%s\" set in rule but not in global methodline",
 			method2string(rule->state.methodv[i]));
 
-	/* if no protocol set, set all. */
+	/* if no protocol set, set all for socks-rules, tcp for client-rules. */
 	if (memcmp(&state.protocol, &rule->state.protocol, sizeof(state.protocol))
 	== 0)
-		memset(&rule->state.protocol, UCHAR_MAX, sizeof(rule->state.protocol));
+		if (client)
+			rule->state.protocol.tcp = 1;
+		else
+			memset(&rule->state.protocol, UCHAR_MAX, sizeof(rule->state.protocol));
 
 	/* if no proxyprotocol set, set all socks protocols. */
 	if (memcmp(&state.proxyprotocol, &rule->state.proxyprotocol,
