@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003
+ * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005
  *      Inferno Nettverk A/S, Norway.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -44,7 +44,7 @@
 #include "common.h"
 
 static const char rcsid[] =
-"$Id: sockd.c,v 1.296 2003/07/01 13:21:42 michaels Exp $";
+"$Id: sockd.c,v 1.301 2005/01/28 10:26:53 michaels Exp $";
 
 	/*
 	 * signal handlers
@@ -53,7 +53,7 @@ static const char rcsid[] =
 __BEGIN_DECLS
 
 static void
-fixsettings __P((void));
+modulesetup __P((void));
 
 static void
 siginfo __P((int sig));
@@ -221,8 +221,7 @@ main(argc, argv, envp)
 	if (dforchild < maxfd) {
 		struct rlimit rlimit;
 
-		rlimit.rlim_cur = maxfd;
-		rlimit.rlim_max = maxfd;
+		rlimit.rlim_cur = rlimit.rlim_max = MIN(maxfd, FD_SETSIZE);
 
 		if (setrlimit(RLIMIT_OFILE, &rlimit) != 0) {
 			if (errno != EPERM)
@@ -741,6 +740,7 @@ serverinit(argc, argv, envp)
 	uid_t euid;
 	int ch, i;
 	int verifyonly = 0;
+	struct rlimit rlimit;
 
 #if !HAVE_PROGNAME
 	if (argv[0] != NULL)
@@ -833,10 +833,8 @@ serverinit(argc, argv, envp)
 		sockscf.option.configfile = SOCKD_CONFIGFILE;
 
 	optioninit();
-
 	genericinit();
-	
-	fixsettings();
+	modulesetup();
 
 	if (verifyonly) {
 		showconfig(&sockscf);
@@ -882,70 +880,18 @@ serverinit(argc, argv, envp)
 				serr(EXIT_FAILURE, "%s: socks_mklock()", function);
 #endif
 	}
-}
 
-static void
-fixsettings(void)
-{
-	const char *function = "fixsettings()";
-	int i;
-	uid_t euid;
+	/* avoid potentioal overflow of fd_set. */
+	if (getrlimit(RLIMIT_OFILE, &rlimit) != 0)
+			serr(EXIT_FAILURE, "getrlimit(RLIMIT_OFILE)");
+	if (rlimit.rlim_cur > FD_SETSIZE) {
+		rlimit.rlim_cur = rlimit.rlim_max = FD_SETSIZE;
 
-	/*
-	 * Check arguments and settings, do they make sense?
-	 */
-
-	if (sockscf.clientmethodc == 0)
-		sockscf.clientmethodv[sockscf.clientmethodc++] = AUTHMETHOD_NONE;
-
-	if (!sockscf.uid.privileged_isset)
-		sockscf.uid.privileged = sockscf.state.euid;
-	else {
-		socks_seteuid(&euid, sockscf.uid.privileged);
-		socks_reseteuid(sockscf.uid.privileged, euid);
+		if (setrlimit(RLIMIT_OFILE, &rlimit) != 0)
+			serr(EXIT_FAILURE, "setrlimit(RLIMIT_OFILE, %d)", rlimit.rlim_cur);
+		slog(LOG_DEBUG, "%s: reduced max descriptors to %d",
+		function, rlimit.rlim_cur);
 	}
-
-	if (!sockscf.uid.unprivileged_isset)
-		sockscf.uid.unprivileged = sockscf.state.euid;
-	else {
-		socks_seteuid(&euid, sockscf.uid.unprivileged);
-		socks_reseteuid(sockscf.uid.unprivileged, euid);
-	}
-
-#if HAVE_LIBWRAP
-	if (!sockscf.uid.libwrap_isset)
-		sockscf.uid.libwrap = sockscf.state.euid;
-	else {
-		socks_seteuid(&euid, sockscf.uid.libwrap);
-		socks_reseteuid(sockscf.uid.libwrap, euid);
-	}
-#endif /* HAVE_LIBWRAP */
-
-	if (sockscf.internalc == 0)
-		serrx(EXIT_FAILURE, "%s: no internal address given", function);
-	/* values will be used once and checked there. */
-
-	if (sockscf.external.addrc == 0)
-		serrx(EXIT_FAILURE, "%s: no external address given", function);
-	for (i = 0; i < sockscf.external.addrc; ++i)
-		if (!addressisbindable(&sockscf.external.addrv[i]))
-			serrx(EXIT_FAILURE, NULL);
-
-	if (sockscf.methodc == 0)
-		swarnx("%s: no methods enabled (total block)", function);
-
-	if (sockscf.uid.unprivileged == 0)
-		swarnx("%s: setting the unprivileged uid to %d is not recommended",
-		function, sockscf.uid.unprivileged);
-
-#if HAVE_LIBWRAP
-	if (sockscf.uid.libwrap == 0)
-		swarnx("%s: setting the libwrap uid to %d is not recommended",
-		function, sockscf.uid.libwrap);
-#endif /* HAVE_LIBWRAP */
-
-	bwsetup();
-	redirectsetup();
 }
 
 /* ARGSUSED */
@@ -1033,7 +979,7 @@ sighup(sig)
 	socks_seteuid(&euid, sockscf.state.euid);
 	genericinit();
 	socks_reseteuid(sockscf.state.euid, euid);
-	fixsettings();
+	modulesetup();
 
 	/* LINTED assignment in conditional context */
 	if ((p = pidismother(sockscf.state.pid))) {
@@ -1123,3 +1069,10 @@ optioninit(void)
 	sockscf.external.rotation	= ROTATION_NONE;
 
 }
+
+static void
+modulesetup(void)
+{
+	bwsetup();
+	redirectsetup();
+}
