@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003
+ * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004
  *      Inferno Nettverk A/S, Norway.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -45,7 +45,7 @@
 #include "config_parse.h"
 
 static const char rcsid[] =
-"$Id: sockd_io.c,v 1.217 2003/07/01 13:21:45 michaels Exp $";
+"$Id: sockd_io.c,v 1.219 2005/01/24 10:24:23 karls Exp $";
 
 /*
  * Accept io objects from mother and does io on them.  We never
@@ -80,8 +80,8 @@ io_finddescriptor __P((int d));
 static int
 io_fillset __P((fd_set *set, int antiflags, const struct timeval *timenow));
 /*
- * Sets all descriptors in our list in the set "set".  If "flags"
- * is set, io's with any of the flags in "flags" set will be excluded.
+ * Sets all descriptors in our list in the set "set".  If "antiflags"
+ * is set, io's with any of the flags in "antiflags" set will be excluded.
  * "timenow" is the time now.
  * Returns the highest descriptor in our list, or -1 if we don't
  * have any descriptors open currently.
@@ -248,7 +248,7 @@ run_io(mother)
 
 	/* same handler, for systems without SIGINFO. */
 	if (sigaction(SIGUSR1, &sigact, NULL) != 0)
-		serr(EXIT_FAILURE, "%s: sigaction(SIGINFO)", function);
+		serr(EXIT_FAILURE, "%s: sigaction(SIGUSR1)", function);
 
 	proctitleupdate();
 
