@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003
+ * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004
  *      Inferno Nettverk A/S, Norway.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -45,7 +45,7 @@
 #include "config_parse.h"
 
 static const char rcsid[] =
-"$Id: sockd_request.c,v 1.153 2003/07/01 13:21:48 michaels Exp $";
+"$Id: sockd_request.c,v 1.155 2005/01/24 10:24:24 karls Exp $";
 
 /*
  * Since it only handles one client at a time there is no possibility
@@ -219,7 +219,7 @@ dorequest(mother, request)
 	struct sockaddr bound;
 	struct sockd_io_t io;
 	struct response_t response;
-	char a[MAXSOCKSHOSTSTRING], b[MAXSOCKSHOSTSTRING];
+	char a[MAXSOCKSHOSTSTRING];
 	char msg[256];
 	int p, permit, out;
 
