@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003
+ * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004
  *      Inferno Nettverk A/S, Norway.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -44,7 +44,7 @@
 #include "common.h"
 
 static const char rcsid[] =
-"$Id: sockd_util.c,v 1.80 2003/07/01 13:21:49 michaels Exp $";
+"$Id: sockd_util.c,v 1.84 2005/01/24 10:24:25 karls Exp $";
 
 #define CM2IM(charmethodv, methodc, intmethodv) \
 	do { \
@@ -118,11 +118,6 @@ setsockoptions(s)
 	socklen_t len;
 	int type, val, bufsize;
 
-#ifdef SO_BSDCOMPAT
-	val = 1;
-	if (setsockopt(s, SOL_SOCKET, SO_BSDCOMPAT, &val, sizeof(val)) != 0)
-		swarn("%s: setsockopt(SO_BSDCOMPAT)", function);
-#endif /* SO_BSDCOMPAT */
 
 	len = sizeof(type);
 	if (getsockopt(s, SOL_SOCKET, SO_TYPE, &type, &len) != 0) {
@@ -264,19 +259,16 @@ socks_seteuid(old, new)
 			SERR(sockscf.state.euid);
 		}
 
-	if (seteuid(new) != 0)
-		serr(EXIT_FAILURE, "%s: seteuid(%d)", function, new);
-
-#if 0 /* he who requested this says it doesn't work but not why. */
-	/* and now groupid. */
-
 	if ((pw = getpwuid(new)) == NULL)
 		serr(EXIT_FAILURE, "%s: getpwuid(%d)", function, new);
 
+	/* groupid ... */
 	if (setegid(pw->pw_gid) != 0)
 		serr(EXIT_FAILURE, "%s: setegid(%d)", function, pw->pw_gid);
-#endif
 
+	/* ... and uid. */
+	if (seteuid(new) != 0)
+		serr(EXIT_FAILURE, "%s: seteuid(%d)", function, new);
 }
 
 void
@@ -305,6 +297,7 @@ socks_reseteuid(current, new)
 		SERR(new);
 
 #if 0 /* he who requested this says it doesn't work but not why. */
+	/* XXX check this again, just wrong order */
 	/*
 	 * and now groupid.
 	 */
